Installation
------------

You can install **Django Magic Notifier** via various ways

PIP::

    > pip install django-magic-notifier

Git::

    > git clone https://github.com/jefcolbi/django-magic-notifier
    > cd django-magic-notifier
    > python setup.py install

